==> haskell-unicode-show-0.1.0.4-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-show
version:              0.1.0.4
visibility:           public
id:                   unicode-show-0.1.0.4-3FCk9qULypzDtc0j6p36c5
key:                  unicode-show-0.1.0.4-3FCk9qULypzDtc0j6p36c5
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           whosekiteneverfly@gmail.com
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  7b70e8e6c66f8eed1b1f2163d1f09a2c
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-8.10.3/site-local/unicode-show-0.1.0.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/unicode-show-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/unicode-show-0.1.0.4
hs-libraries:         HSunicode-show-0.1.0.4-3FCk9qULypzDtc0j6p36c5
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.0.4-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-show
version:              0.1.0.4
visibility:           public
id:                   unicode-show-0.1.0.4-Is39A0DFsTKDWsPJSAThBX
key:                  unicode-show-0.1.0.4-Is39A0DFsTKDWsPJSAThBX
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           whosekiteneverfly@gmail.com
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  5429f4b5846f6e817f13e24bbbcb9dfb
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-8.10.3/site-local/unicode-show-0.1.0.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/unicode-show-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/unicode-show-0.1.0.4
hs-libraries:         HSunicode-show-0.1.0.4-Is39A0DFsTKDWsPJSAThBX
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
